Ishtar
======

[![build status](https://gitlab.com/iggdrasil/ishtar/badges/master/build.svg)](https://gitlab.com/iggdrasil/ishtar/commits/master)

Description
-----------

A full description of this project and news about Ishtar are available on this [website](http://www.ishtar-archeo.net).

Docs
----

Documentation is not yet available but help can be provided on the [forum](http://forum.ishtar-archeo.net).
